==> gdm-settings-1.1-x86_64-1_gfs.txz: usr/doc/gdm-settings-1.1/README.md <==
<p align="center">
  <img src="data/icons/io.github.realmazharhussain.GdmSettings.svg" alt="GDM Settings Icon" width="100" height="100">
</p>

<h1 align="center">Login Manager Settings</h1>

<div align="center">
  <p><strong>A settings app for GNOME's Login/Display Manager, GDM.</strong></p>
  <p>It is written in Python and uses LibAdwaita for graphical interface.</p>
</div>

<br>

<div align="center">
  <a href="https://github.com/realmazharhussain/gdm-settings/releases/latest"><img alt="Downloads"
      src="https://img.shields.io/github/downloads/realmazharhussain/gdm-settings/total"></a>
  <a href="https://github.com/realmazharhussain/gdm-settings/wiki/Install"><img alt="Flatpak Installs"
      src="https://img.shields.io/flathub/downloads/io.github.realmazharhussain.GdmSettings"></a>
  <a href="#"><img alt="Code Size"
      src="https://img.shields.io/github/languages/code-size/realmazharhussain/gdm-settings"></a>
  <a href="https://hosted.weblate.org/projects/gdm-settings/#languages"><img alt="Translation Status"
      src="https://hosted.weblate.org/widgets/gdm-settings/-/svg-badge.svg"></a>
</div>

<div align="center">
  <h2>
    <a href="https://github.com/realmazharhussain/gdm-settings/wiki/Install">Install</a>
  </h2>
</div>

<div align="center">
  <h3>
    <a href="https://github.com/realmazharhussain/gdm-settings/wiki/Features">Features</a>
    <span> | </span>
    <a href="https://github.com/realmazharhussain/gdm-settings/wiki/Screenshots">Screenshots</a>
    <span> | </span>
    <a href="https://github.com/realmazharhussain/gdm-settings/wiki">Wiki</a>
  </h3>
</div>

<div align="center">
  <a href="https://github.com/realmazharhussain/gdm-settings/wiki/Screenshots">
    <picture>
      <source srcset="https://github.com/realmazharhussain/gdm-settings/wiki/screenshots/bleeding-edge-dark.png" media="(prefers-color-scheme: dark)">
      <img src="https://github.com/realmazharhussain/gdm-settings/wiki/screenshots/bleeding-edge.png">
    </picture>
  </a>
</div>

<div align="center">
  <h4>
    <a href="https://hosted.weblate.org/engage/gdm-settings">Translate</a>
    <span> | </span>
    <a href="https://github.com/realmazharhussain/gdm-settings/issues/new?assignees=&labels=bug&template=bug_report.yml">Report Bugs</a>
    <span> | </span>
    <a href="https://www.patreon.com/mazharhussain">Donate</a>
  </h4>
</div>

==> gdm-settings-2.0-x86_64-1_gfs.txz: usr/doc/gdm-settings-2.0/README.md <==
<p align="center">
  <img src="data/icons/io.github.realmazharhussain.GdmSettings.svg" alt="GDM Settings Icon" width="100" height="100">
</p>

<h1 align="center">Login Manager Settings</h1>

<div align="center">
  <p><strong>A settings app for GNOME's Login/Display Manager, GDM.</strong></p>
  <p>It is written in Python and uses LibAdwaita for graphical interface.</p>
</div>

<br>

<div align="center">
  <a href="https://github.com/realmazharhussain/gdm-settings/releases/latest"><img alt="Downloads"
      src="https://img.shields.io/github/downloads/realmazharhussain/gdm-settings/total"></a>
  <a href="https://github.com/realmazharhussain/gdm-settings/wiki/Install"><img alt="Flatpak Installs"
      src="https://img.shields.io/flathub/downloads/io.github.realmazharhussain.GdmSettings"></a>
  <a href="#"><img alt="Code Size"
      src="https://img.shields.io/github/languages/code-size/realmazharhussain/gdm-settings"></a>
  <a href="https://hosted.weblate.org/projects/gdm-settings/language-names"><img alt="Translation Status"
      src="https://hosted.weblate.org/widgets/gdm-settings/-/svg-badge.svg"></a>
</div>

<div align="center">
  <h2>
    <a href="https://github.com/realmazharhussain/gdm-settings/releases/latest/download/Login_Manager_Settings.AppImage">Download</a>
    <span> | </span>
    <a href="https://github.com/realmazharhussain/gdm-settings/wiki/Install">Install</a>
  </h2>
</div>

<div align="center">
  <a href="https://github.com/realmazharhussain/gdm-settings/wiki/Screenshots">
    <picture>
      <source srcset="https://github.com/realmazharhussain/gdm-settings/wiki/screenshots/bleeding-edge-dark.png" media="(prefers-color-scheme: dark)">
      <img src="https://github.com/realmazharhussain/gdm-settings/wiki/screenshots/bleeding-edge.png">
    </picture>
  </a>
</div>

<div align="center">
  <h3>
    <a href="https://github.com/realmazharhussain/gdm-settings/wiki/Screenshots">Screenshots</a>
    <span> | </span>
    <a href="https://github.com/realmazharhussain/gdm-settings/wiki">Wiki</a>
  </h3>
</div>

<div align="center">
  <h4>
    <a href="https://hosted.weblate.org/engage/gdm-settings">Translate</a>
    <span> | </span>
    <a href="https://github.com/realmazharhussain/gdm-settings/issues/new?assignees=&labels=bug&template=bug_report.yml">Report Bugs</a>
    <span> | </span>
    <a href="https://www.patreon.com/mazharhussain">Donate</a>
  </h4>
</div>
